@@ -16,6 +16,11 @@ typedef enum cffi_enumdocumented
     CFFI_C = 2,
     } cffi_enumdocumented;
 
+typedef enum cffi_enumrenamed
+    {
+    CFFI_X = 0,
+    } cffi_enumrenamed;
+
 typedef struct cffi_generic2u8 cffi_generic2u8;
 typedef struct cffi_generic3 cffi_generic3;
 typedef struct cffi_generic4 cffi_generic4;
@@ -57,6 +62,11 @@ typedef struct cffi_structdocumented
     float x;
     } cffi_structdocumented;
 
+typedef struct cffi_structrenamed
+    {
+    cffi_enumrenamed e;
+    } cffi_structrenamed;
+
 typedef struct cffi_tupled
     {
     uint8_t x0;
@@ -139,6 +149,12 @@ typedef cffi_tupled (*cffi_fptr_fn_Tupled_rval_Tupled)(cffi_tupled x0);
 
 typedef bool (*cffi_fptr_fn_pmut_i64_rval_bool)(int64_t* x0);
 
+typedef struct cffi_ffisliceffibool
+    {
+    uint8_t* data;
+    uint64_t len;
+    } cffi_ffisliceffibool;
+
 typedef struct cffi_ffisliceu32
     {
     uint32_t* data;
@@ -219,6 +235,7 @@ cffi_vec2 ambiguous_2(cffi_vec2 x);
 bool ambiguous_3(cffi_vec1 x, cffi_vec2 y);
 cffi_vec namespaced_type(cffi_vec x);
 cffi_ffierror panics();
+cffi_enumrenamed renamed(cffi_structrenamed x);
 void sleep(uint64_t millis);
 bool weird_1(cffi_weird1u32 _x, cffi_weird2u8 _y);
 void visibility(cffi_visibility1 _x, cffi_visibility2 _y);
@@ -246,11 +263,11 @@ cffi_ffierror simple_service_destroy(cffi_simpleservice** context_ptr);
 cffi_ffierror simple_service_result(cffi_simpleservice* context_ptr, uint32_t x);
 uint32_t simple_service_value(cffi_simpleservice* context_ptr, uint32_t x);
 uint8_t simple_service_mut_self(cffi_simpleservice* context_ptr, cffi_ffisliceu8 slice);
-void simple_service_mut_self_void(cffi_simpleservice* context_ptr, cffi_ffisliceu8 slice);
+void simple_service_mut_self_void(cffi_simpleservice* context_ptr, cffi_ffisliceffibool slice);
 uint8_t simple_service_mut_self_ref(cffi_simpleservice* context_ptr, uint8_t* x, uint8_t* _y);
 uint8_t simple_service_mut_self_ref_slice(cffi_simpleservice* context_ptr, uint8_t* x, uint8_t* _y, cffi_ffisliceu8 _slice);
 uint8_t simple_service_mut_self_ref_slice_limited(cffi_simpleservice* context_ptr, uint8_t* x, uint8_t* _y, cffi_ffisliceu8 _slice, cffi_ffisliceu8 _slice2);
-cffi_ffierror simple_service_mut_self_ffi_error(cffi_simpleservice* context_ptr, cffi_ffisliceu8 slice);
+cffi_ffierror simple_service_mut_self_ffi_error(cffi_simpleservice* context_ptr, cffi_ffislicemutu8 slice);
 void simple_service_void(cffi_simpleservice* context_ptr);
 uint32_t simple_service_extra_method(cffi_simpleservice* _context);
 """
@@ -284,6 +301,11 @@ class EnumDocumented:
     C = 2
 
 
+class EnumRenamed:
+    """"""
+    X = 0
+
+
 class Array(object):
     """"""
     def __init__(self):
@@ -514,6 +536,29 @@ class StructDocumented(object):
         self._ptr_x = value
         self._ctx[0].x = value
 
+class StructRenamed(object):
+    """"""
+    def __init__(self):
+        global _api, ffi
+        self._ctx = ffi.new("cffi_structrenamed[]", 1)
+
+    def array(n):
+        global _api, ffi
+        return ffi.new("cffi_structrenamed[]", n)
+
+    def ptr(self):
+        return self._ctx
+
+    @property
+    def e(self):
+        """"""
+        return self._ctx[0].e
+
+    @e.setter
+    def e(self, value):
+        self._ptr_e = value
+        self._ctx[0].e = value
+
 class Tupled(object):
     """"""
     def __init__(self):
@@ -1152,6 +1197,13 @@ Parameter x must point to valid data."""
         global _api
         return _api.panics()
 
+    def renamed(x):
+        """"""
+        global _api
+        if hasattr(x, "_ctx"):
+            x = x._ctx[0]
+        return _api.renamed(x)
+
     def sleep(millis):
         """"""
         global _api
